@@ -12,7 +12,7 @@ import sys
 
 from .bus.redis import RedisBus
 from .config import Config
-from .context import register_backends
+from .context import register_backends, register_plugins
 from .cron.scheduler import CronScheduler
 from .event.processor import EventProcessor
 from .logger import Logger
@@ -20,11 +20,10 @@ from .message.event import Event
 from .message.event.application import ApplicationStartedEvent
 from .message.request import Request
 from .message.response import Response
-from .utils import set_thread_name
-
+from .utils import set_thread_name, get_enabled_plugins
 
 __author__ = 'Fabio Manganiello <info@fabiomanganiello.com>'
-__version__ = '0.21.2'
+__version__ = '0.21.4'
 
 logger = logging.getLogger('platypush')
 
@@ -160,9 +159,15 @@ class Daemon:
 
     def stop_app(self):
         """ Stops the backends and the bus """
+        from .plugins import RunnablePlugin
+
         for backend in self.backends.values():
             backend.stop()
 
+        for plugin in get_enabled_plugins().values():
+            if isinstance(plugin, RunnablePlugin):
+                plugin.stop()
+
         self.bus.stop()
         if self.cron_scheduler:
             self.cron_scheduler.stop()
@@ -184,6 +189,9 @@ class Daemon:
         for backend in self.backends.values():
             backend.start()
 
+        # Initialize the plugins
+        register_plugins(bus=self.bus)
+
         # Start the cron scheduler
         if Config.get_cronjobs():
             self.cron_scheduler = CronScheduler(jobs=Config.get_cronjobs())
