@@ -132,16 +132,21 @@ class PushbulletBackend(Backend):
         self.close()
         self.logger.info('Pushbullet backend terminated')
 
-    def on_error(self, e):
-        self.logger.exception(e)
-        self.close()
-        self.run_listener()
+    def on_close(self, err=None):
+        self.listener = None
+        raise RuntimeError(err or 'Connection closed')
+
+    def on_open(self):
+        self.logger.info('Pushbullet service connected')
 
     def run_listener(self):
-        from pushbullet import Listener
+        from .listener import Listener
 
         self.logger.info('Initializing Pushbullet backend - device_id: {}'.format(self.device_name))
-        self.listener = Listener(account=self.pb, on_push=self.on_push(), on_error=self.on_error,
+        self.listener = Listener(account=self.pb, on_push=self.on_push(),
+                                 on_open=self.on_open,
+                                 on_close=self.on_close,
+                                 on_error=self.on_close,
                                  http_proxy_host=self.proxy_host,
                                  http_proxy_port=self.proxy_port)
 
@@ -159,9 +164,16 @@ class PushbulletBackend(Backend):
             except Exception as e:
                 self.logger.exception(e)
                 self.logger.error('Pushbullet initialization error: {}'.format(str(e)))
-                time.sleep(30)
+                time.sleep(10)
+
+        while not self.should_stop():
+            try:
+                self.run_listener()
+            except Exception as e:
+                self.logger.exception(e)
+                time.sleep(10)
+                self.logger.info('Retrying connection')
 
-        self.run_listener()
 
 
 # vim:sw=4:ts=4:et:
